==> paygilant_plugin-2.2.30.tar.gz: android/src/main/java/com/example/paygilant_plugin/PaygilantPlugin.java <==
package com.example.paygilant_plugin;

import android.Manifest;
import android.app.Activity;
import android.content.Context;
import android.content.pm.PackageManager;
import android.os.Build;

import androidx.annotation.NonNull;

import com.paygilant.PG_FraudDetection_SDK.Biometric.PaygilantScreenListener;
import com.paygilant.PG_FraudDetection_SDK.Communication.PaygilantCommunication;
import com.paygilant.PG_FraudDetection_SDK.PaygilantException;
import com.paygilant.PG_FraudDetection_SDK.PaygilantManager;
import com.paygilant.pgdata.CheckPoint.AddPaymentMethod;
import com.paygilant.pgdata.CheckPoint.CheckPoint;
import com.paygilant.pgdata.CheckPoint.CheckPointStatus;
import com.paygilant.pgdata.CheckPoint.CheckPointType;
import com.paygilant.pgdata.CheckPoint.General;
import com.paygilant.pgdata.CheckPoint.Launch;
import com.paygilant.pgdata.CheckPoint.Login;
import com.paygilant.pgdata.CheckPoint.ExternalCardTransaction;
import com.paygilant.pgdata.CheckPoint.PasswordChange;
import com.paygilant.pgdata.CheckPoint.ViewCardDetails;
import com.paygilant.pgdata.CheckPoint.Registration;
import com.paygilant.pgdata.CheckPoint.ScreenListenerType;
import com.paygilant.pgdata.CheckPoint.Transaction;
import com.paygilant.pgdata.CheckPoint.UpdateUserInfo;
import org.json.JSONException;
import org.json.JSONObject;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.HashSet;
import java.util.LinkedHashMap;
import java.util.LinkedList;
import java.util.List;
import java.util.Map;
import java.util.Set;
import io.flutter.Log;
import io.flutter.embedding.engine.plugins.FlutterPlugin;
import io.flutter.embedding.engine.plugins.activity.ActivityAware;
import io.flutter.embedding.engine.plugins.activity.ActivityPluginBinding;
import io.flutter.plugin.common.BinaryMessenger;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import io.flutter.plugin.common.PluginRegistry.Registrar;

/** PaygilantPlugin */
public class PaygilantPlugin implements FlutterPlugin, MethodCallHandler , ActivityAware {
  /// The MethodChannel that will the communication between Flutter and native Android
  ///
  /// This local reference serves to register the plugin with the Flutter Engine and unregister it
  /// when the Flutter Engine is detached from the Activity
  private MethodChannel channel;
  private PaygilantScreenListener screenListener;
  private Activity activity;

  @Override
  public void onAttachedToEngine(@NonNull FlutterPluginBinding flutterPluginBinding) {
    onAttach(flutterPluginBinding.getBinaryMessenger());  // <- this is the line we need here, a new method call
    channel = new MethodChannel(flutterPluginBinding.getFlutterEngine().getDartExecutor(), "paygilant_plugin");
    channel.setMethodCallHandler(this);
  }

  private void onAttach(BinaryMessenger messenger) {
    channel = new MethodChannel(messenger, "paygilant_plugin");
    channel.setMethodCallHandler(new PaygilantPlugin());
  }
  // This static function is optional and equivalent to onAttachedToEngine. It supports the old
  // pre-Flutter-1.12 Android projects. You are encouraged to continue supporting
  // plugin registration via this function while apps migrate to use the new Android APIs
  // post-flutter-1.12 via https://flutter.dev/go/android-project-migration.
  //
  // It is encouraged to share logic between onAttachedToEngine and registerWith to keep
  // them functionally equivalent. Only one of onAttachedToEngine or registerWith will be called
  // depending on the user's project. onAttachedToEngine or registerWith must both be defined
  // in the same class.
//  public static void registerWith(Registrar registrar) {
//    final MethodChannel channel = new MethodChannel(registrar.messenger(), "paygilant_plugin");
//    final Context context = registrar.context();
//    channel.setMethodCallHandler(new PaygilantPlugin());
//  }

  @Override
  public void onMethodCall(@NonNull MethodCall call, @NonNull final Result result) {
    switch (call.method) {
      case "getPlatformVersion":
        result.success("Android " + android.os.Build.VERSION.RELEASE);
        break;
      case "init":
        String serverUrl = call.argument("serverUrl");
        String userId = call.argument("userId");
        try {
          PaygilantManager.init(activity.getApplicationContext(), serverUrl, userId);
        } catch (PaygilantException e) {
          result.error(e.getMessage(),e.getCause().getMessage(),e);
            e.printStackTrace();
        }
        break;
      case "setUserId":
        String userID = call.argument("userId");
        PaygilantManager.getInstance(activity.getApplicationContext()).setUserId(userID);
        break;
      case "initializeDeviceId":
        PaygilantManager.getInstance(activity.getApplicationContext()).initializeDeviceId();
        break;
      case "logout":
        PaygilantManager.getInstance(activity.getApplicationContext()).logout();
        break;
      case "getDeviceId":
        result.success(PaygilantManager.getInstance(activity.getApplicationContext()).getDeviceId());
        break;
      case "getSessionId":
        result.success(PaygilantManager.getInstance(activity.getApplicationContext()).getSessionId());
        break;
      case "getRiskForCheckPoint":

        String jsonStr = call.argument("checkpoint").toString();
        CheckPoint checkPoint = getCheckPointFromJson(jsonStr);
        if (checkPoint != null) {
          PaygilantManager.getInstance(activity.getApplicationContext()).getRiskForCheckPoint(checkPoint, new PaygilantCommunication() {
            @Override
            public void receiveRisk(int riskLevel, String signedRisk, String requestId) {
              JSONObject jsonObject = new JSONObject();
              try {
                jsonObject.put("riskLevel", riskLevel);
                jsonObject.put("signedRisk", signedRisk);
                jsonObject.put("requestId", requestId);

              } catch (JSONException e) {
                e.printStackTrace();
              }
              result.success(jsonObject.toString());
            }
          });
        }
        break;
      case "arriveToCheckPoint":

        String jsonStrArrive = call.argument("checkpoint").toString();
        CheckPoint checkPointArrive = getCheckPointFromJson(jsonStrArrive);
        if (checkPointArrive != null) {
          PaygilantManager.getInstance(activity.getApplicationContext()).arriveToCheckPoint(checkPointArrive);
        }
        break;
      case "onRequestPermissionsResult":
        ArrayList<String> permissionsResult = call.argument("permissions");
        HashSet<String> permissions = new HashSet<>();

        for (String permissionStr : permissionsResult) {
          permissions.addAll(parsePremissionToNative(permissionStr));
        }
        int [] grantResults = new int[permissions.size()];
        int i = 0;
        for (String permission:permissions){

          if (checkSelfPermission(activity.getApplicationContext(),permission)) {
            grantResults[i] = 0;
          }else{
            grantResults[i] = -1;
            }
          i++;
          }
        String [] permissionsResults = permissions.toArray(new String[permissions.size()]);
        PaygilantManager.getInstance(activity.getApplicationContext()).onRequestPermissionsResult(0,permissionsResults,grantResults);
        break;

      case "updateCheckPointStatus":
        CheckPointType checkPointType = CheckPointType.valueOf(call.argument("checkPointType").toString());
        String requestId = call.argument("requestID").toString();
        CheckPointStatus checkPointStatus = CheckPointStatus.valueOf(call.argument("checkPointStatus").toString());
        String transactionId = call.argument("transactionID").toString();
        PaygilantManager.getInstance(activity.getApplicationContext()).updateCheckPointStatus(checkPointType, requestId, checkPointStatus, transactionId);
        break;
      case "startNewScreenListener":
        final String screenListenerType = call.argument("screenListenerType");
        Integer screenId = call.argument("screenId");
        
          screenListener = PaygilantManager.getInstance(activity.getApplicationContext()).startNewScreenListener(ScreenListenerType.valueOf(screenListenerType),screenId, activity);
        break;
      case "pauseListenToSensors":
        if (screenListener != null) {
          screenListener.pauseListenToSensors();
        }
        break;
      default:
        result.notImplemented();
    }
  }
  public static int[] convertIntegers(List<Integer> integers)
  {
    int[] ret = new int[integers.size()];
    for (int i=0; i < ret.length; i++)
    {
      ret[i] = integers.get(i).intValue();
    }
    return ret;
  }
public static Boolean checkSelfPermission(Context context, String permission) {
  PackageManager mPackageManager = context.getPackageManager();
  int hasPermStorage = mPackageManager.checkPermission(permission, context.getPackageName());
  if (hasPermStorage != PackageManager.PERMISSION_GRANTED) {
    return false;
  } else if (hasPermStorage == PackageManager.PERMISSION_GRANTED) {
    return true;
  }else
    return false;
}
class PermissionResult {
    private String permission;
    private Integer grantResult;

  public PermissionResult(String permission, Integer grantResult) {
    this.permission = permission;
    this.grantResult = grantResult;
  }

  public String getPermission() {
    return permission;
  }

  public void setPermission(String permission) {
    this.permission = permission;
  }

  public Integer getGrantResult() {
    return grantResult;
  }

  public void setGrantResult(Integer grantResult) {
    this.grantResult = grantResult;
  }
}
private List<String> parsePremissionToNative(String permissionFlutter){

    List<String> permissionList = new ArrayList<>();

  switch (permissionFlutter) {
    case "calendar":
      permissionList.add(( Manifest.permission.READ_CALENDAR));
      break;
    case "camera":
      permissionList.add(( Manifest.permission.CAMERA));
      break;
    case "contacts":
      permissionList.add(( Manifest.permission.READ_CONTACTS));
      permissionList.add(( Manifest.permission.GET_ACCOUNTS));

      break;
    case "location":
      permissionList.add(( Manifest.permission.ACCESS_COARSE_LOCATION));
      permissionList.add(( Manifest.permission.ACCESS_FINE_LOCATION));

      break;
    case "locationAlways":
      permissionList.add(( Manifest.permission.ACCESS_COARSE_LOCATION));
      permissionList.add(( Manifest.permission.ACCESS_FINE_LOCATION));
      break;
    case "locationWhenInUse":
      permissionList.add(( Manifest.permission.ACCESS_COARSE_LOCATION));
      permissionList.add(( Manifest.permission.ACCESS_FINE_LOCATION));
      break;
    case "phone":
      permissionList.add(( Manifest.permission.READ_CALL_LOG));
      permissionList.add(( Manifest.permission.READ_PHONE_STATE));
      break;
    case "storage":
      permissionList.add(( Manifest.permission.READ_EXTERNAL_STORAGE));
      permissionList.add(( Manifest.permission.WRITE_EXTERNAL_STORAGE));
      break;
    default:
      break;
  }


  return permissionList;

}

//  private PermissionResult AddToLists(String premission) {
//    Integer grandPremission;
//    if (checkSelfPermission(activity.getApplicationContext(), premission)) {
//      grandPremission = 1;
//    } else {
//      grandPremission = 0;
//    }
//    return new PermissionResult(premission,grandPremission);
//  }

  private CheckPoint getCheckPointFromJson(String jsonStr) {
    try {
      Log.d("Json string from JS: ", jsonStr);
      JSONObject object = new JSONObject(jsonStr);
      CheckPoint checkPoint;

      String checkPointType = object.getString("checkpoint_type");
      if (CheckPointType.valueOf(checkPointType) == CheckPointType.LAUNCH) {
        Launch launch = new Launch();
        checkPoint = launch;
      } else if (CheckPointType.valueOf(checkPointType) == CheckPointType.REGISTER) {
        checkPoint = new Registration(object);
      } else if (CheckPointType.valueOf(checkPointType) == CheckPointType.LOGIN) {
        checkPoint = new Login(object);
      } else if (CheckPointType.valueOf(checkPointType) == CheckPointType.TRANSACTION) {
        checkPoint = new Transaction(object);
      } else if (CheckPointType.valueOf(checkPointType) == CheckPointType.ADD_PAYMENT_METHOD) {
        checkPoint = new AddPaymentMethod(object);
      } else if (CheckPointType.valueOf(checkPointType) == CheckPointType.PASSWORD_CHANGE) {
        checkPoint = new PasswordChange(object);
      } else if (CheckPointType.valueOf(checkPointType) == CheckPointType.VIEW_CARD_DETAILS) {
        checkPoint = new ViewCardDetails(object);  
      } else if (CheckPointType.valueOf(checkPointType) == CheckPointType.UPDATE_USER_INFO) {
        checkPoint = new UpdateUserInfo(object);
      } else if (CheckPointType.valueOf(checkPointType) == CheckPointType.EXTERNAL_CARD_TRANSACTION) {
        checkPoint = new ExternalCardTransaction(object);
      } else { // if (CheckPointType.valueOf(checkPointType) == CheckPointType.GENERAL) {
        checkPoint = new General();
      }
      return checkPoint;
    } catch (JSONException e) {
      return null;
    }
  }

  @Override
  public void onDetachedFromActivityForConfigChanges() {

  }

  @Override
  public void onReattachedToActivityForConfigChanges(@NonNull ActivityPluginBinding binding) {

  }

  @Override
  public void onDetachedFromActivity() {

  }

  @Override
  public void onDetachedFromEngine(@NonNull FlutterPluginBinding binding) {

    channel.setMethodCallHandler(null);
  }

  @Override
  public void onAttachedToActivity(@NonNull ActivityPluginBinding binding) {
    activity = binding.getActivity();

  }
}

==> paygilant_plugin-2.2.39.tar.gz: android/src/main/java/com/example/paygilant_plugin/PaygilantPlugin.java <==
package com.example.paygilant_plugin;

import android.Manifest;
import android.app.Activity;
import android.content.Context;
import android.content.pm.PackageManager;
import android.os.Build;

import androidx.annotation.NonNull;

import com.paygilant.PG_FraudDetection_SDK.Biometric.PaygilantScreenListener;
import com.paygilant.PG_FraudDetection_SDK.Communication.PaygilantCommunication;
import com.paygilant.PG_FraudDetection_SDK.PaygilantException;
import com.paygilant.PG_FraudDetection_SDK.PaygilantManager;
import com.paygilant.PG_FraudDetection_SDK.PaygilantRunTimeException;
import com.paygilant.pgdata.CheckPoint.AddPaymentMethod;
import com.paygilant.pgdata.CheckPoint.CheckPoint;
import com.paygilant.pgdata.CheckPoint.CheckPointStatus;
import com.paygilant.pgdata.CheckPoint.CheckPointType;
import com.paygilant.pgdata.CheckPoint.General;
import com.paygilant.pgdata.CheckPoint.Launch;
import com.paygilant.pgdata.CheckPoint.Login;
import com.paygilant.pgdata.CheckPoint.ExternalCardTransaction;
import com.paygilant.pgdata.CheckPoint.PasswordChange;
import com.paygilant.pgdata.CheckPoint.ViewCardDetails;
import com.paygilant.pgdata.CheckPoint.Registration;
import com.paygilant.pgdata.CheckPoint.ScreenListenerType;
import com.paygilant.pgdata.CheckPoint.Transaction;
import com.paygilant.pgdata.CheckPoint.UpdateUserInfo;
import org.json.JSONException;
import org.json.JSONObject;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.HashSet;
import java.util.LinkedHashMap;
import java.util.LinkedList;
import java.util.List;
import java.util.Map;
import java.util.Set;
import io.flutter.Log;
import io.flutter.embedding.engine.plugins.FlutterPlugin;
import io.flutter.embedding.engine.plugins.activity.ActivityAware;
import io.flutter.embedding.engine.plugins.activity.ActivityPluginBinding;
import io.flutter.plugin.common.BinaryMessenger;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import io.flutter.plugin.common.PluginRegistry.Registrar;

/** PaygilantPlugin */
public class PaygilantPlugin implements FlutterPlugin, MethodCallHandler , ActivityAware {
  /// The MethodChannel that will the communication between Flutter and native Android
  ///
  /// This local reference serves to register the plugin with the Flutter Engine and unregister it
  /// when the Flutter Engine is detached from the Activity
  private MethodChannel channel;
  private PaygilantScreenListener screenListener;
  private Activity activity;

  @Override
  public void onAttachedToEngine(@NonNull FlutterPluginBinding flutterPluginBinding) {
    onAttach(flutterPluginBinding.getBinaryMessenger());  // <- this is the line we need here, a new method call
    channel = new MethodChannel(flutterPluginBinding.getFlutterEngine().getDartExecutor(), "paygilant_plugin");
    channel.setMethodCallHandler(this);
  }

  private void onAttach(BinaryMessenger messenger) {
    channel = new MethodChannel(messenger, "paygilant_plugin");
    channel.setMethodCallHandler(new PaygilantPlugin());
  }
  // This static function is optional and equivalent to onAttachedToEngine. It supports the old
  // pre-Flutter-1.12 Android projects. You are encouraged to continue supporting
  // plugin registration via this function while apps migrate to use the new Android APIs
  // post-flutter-1.12 via https://flutter.dev/go/android-project-migration.
  //
  // It is encouraged to share logic between onAttachedToEngine and registerWith to keep
  // them functionally equivalent. Only one of onAttachedToEngine or registerWith will be called
  // depending on the user's project. onAttachedToEngine or registerWith must both be defined
  // in the same class.
//  public static void registerWith(Registrar registrar) {
//    final MethodChannel channel = new MethodChannel(registrar.messenger(), "paygilant_plugin");
//    final Context context = registrar.context();
//    channel.setMethodCallHandler(new PaygilantPlugin());
//  }

  @Override
  public void onMethodCall(@NonNull MethodCall call, @NonNull final Result result) {
    switch (call.method) {
      case "getPlatformVersion":
        result.success("Android " + android.os.Build.VERSION.RELEASE);
        break;
      case "init":
        String serverUrl = call.argument("serverUrl");
        String userId = call.argument("userId");
        try {
          PaygilantManager.init(activity.getApplicationContext(), serverUrl, userId);
        } catch (PaygilantException e) {
          result.error(e.getClass().toString(),e.getMessage(),e);
        }
        break;
      case "setUserId":
        String userID = call.argument("userId");
        try {
          PaygilantManager.getInstance(activity.getApplicationContext()).setUserId(userID);
        }catch (PaygilantRunTimeException e){
          result.error(e.getClass().toString(),e.getMessage(),e);
        }
        break;
      case "initializeDeviceId":
        try{
          PaygilantManager.getInstance(activity.getApplicationContext()).initializeDeviceId();
        }catch (PaygilantRunTimeException e){
          result.error(e.getClass().toString(),e.getMessage(),e);
        }
        break;
      case "logout":
        try {
          PaygilantManager.getInstance(activity.getApplicationContext()).logout();
        }catch (PaygilantRunTimeException e){
          result.error(e.getClass().toString(),e.getMessage(),e);
        }
        break;
      case "getDeviceId":
        try {
          result.success(PaygilantManager.getInstance(activity.getApplicationContext()).getDeviceId());
        }catch (PaygilantRunTimeException e){
          result.error(e.getClass().toString(),e.getMessage(),e);
        }
        break;
      case "getSessionId":
        try {
          result.success(PaygilantManager.getInstance(activity.getApplicationContext()).getSessionId());
        }catch (PaygilantRunTimeException e){
          result.error(e.getClass().toString(),e.getMessage(),e);
        }
        break;
      case "getRiskForCheckPoint":
        String jsonStr = call.argument("checkpoint").toString();
        CheckPoint checkPoint = getCheckPointFromJson(jsonStr);
        if (checkPoint != null) {
          try {
            PaygilantManager.getInstance(activity.getApplicationContext()).getRiskForCheckPoint(checkPoint, new PaygilantCommunication() {
              @Override
              public void receiveRisk(int riskLevel, String signedRisk, String requestId) {
                JSONObject jsonObject = new JSONObject();
                try {
                  jsonObject.put("riskLevel", riskLevel);
                  jsonObject.put("signedRisk", signedRisk);
                  jsonObject.put("requestId", requestId);

                } catch (JSONException e) {
                  e.printStackTrace();
                }
                result.success(jsonObject.toString());
              }
            });
          }catch (PaygilantRunTimeException e){
            JSONObject jsonObject = new JSONObject();
            try {
              jsonObject.put("riskLevel", -1);
              jsonObject.put("signedRisk", "-1");
              jsonObject.put("requestId", "");

            } catch (JSONException jsonException) {
              jsonException.printStackTrace();
            }
            result.success(jsonObject.toString());
            e.printStackTrace();
          }
        }
        break;
      case "arriveToCheckPoint":

        String jsonStrArrive = call.argument("checkpoint").toString();
        CheckPoint checkPointArrive = getCheckPointFromJson(jsonStrArrive);
        if (checkPointArrive != null) {
          try {
            PaygilantManager.getInstance(activity.getApplicationContext()).arriveToCheckPoint(checkPointArrive);
          }catch (PaygilantRunTimeException e){
            result.error(e.getClass().toString(),e.getMessage(),e);
          }
        }else{
          result.error("CheckPoint is null","CheckPoint is null","");
        }
        break;
      case "onRequestPermissionsResult":
        ArrayList<String> permissionsResult = call.argument("permissions");
        HashSet<String> permissions = new HashSet<>();

        for (String permissionStr : permissionsResult) {
          permissions.addAll(parsePremissionToNative(permissionStr));
        }
        int [] grantResults = new int[permissions.size()];
        int i = 0;
        for (String permission:permissions){

          if (checkSelfPermission(activity.getApplicationContext(),permission)) {
            grantResults[i] = 0;
          }else{
            grantResults[i] = -1;
            }
          i++;
          }
        String [] permissionsResults = permissions.toArray(new String[permissions.size()]);
        try {
          PaygilantManager.getInstance(activity.getApplicationContext()).onRequestPermissionsResult(0, permissionsResults, grantResults);
        }catch (PaygilantRunTimeException e){
          result.error(e.getClass().toString(),e.getMessage(),e);
        }
        break;

      case "updateCheckPointStatus":
        CheckPointType checkPointType = CheckPointType.valueOf(call.argument("checkPointType").toString());
        String requestId = call.argument("requestID").toString();
        CheckPointStatus checkPointStatus = CheckPointStatus.valueOf(call.argument("checkPointStatus").toString());
        String transactionId = call.argument("transactionID").toString();
        try {
          PaygilantManager.getInstance(activity.getApplicationContext()).updateCheckPointStatus(checkPointType, requestId, checkPointStatus, transactionId);
        }catch (PaygilantRunTimeException e){
          result.error(e.getClass().toString(),e.getMessage(),e);
        }
        break;
      case "startNewScreenListener":
        final String screenListenerType = call.argument("screenListenerType");
        Integer screenId = call.argument("screenId");

        try {
          screenListener = PaygilantManager.getInstance(activity.getApplicationContext()).startNewScreenListener(ScreenListenerType.valueOf(screenListenerType), screenId, activity);
        }catch (PaygilantRunTimeException e){
          result.error(e.getClass().toString(),e.getMessage(),e);
        }
          break;
      case "pauseListenToSensors":
        if (screenListener != null) {
          screenListener.pauseListenToSensors();
        }
        break;
      default:
        result.notImplemented();
    }
  }
  public static int[] convertIntegers(List<Integer> integers)
  {
    int[] ret = new int[integers.size()];
    for (int i=0; i < ret.length; i++)
    {
      ret[i] = integers.get(i).intValue();
    }
    return ret;
  }
public static Boolean checkSelfPermission(Context context, String permission) {
  PackageManager mPackageManager = context.getPackageManager();
  int hasPermStorage = mPackageManager.checkPermission(permission, context.getPackageName());
  if (hasPermStorage != PackageManager.PERMISSION_GRANTED) {
    return false;
  } else if (hasPermStorage == PackageManager.PERMISSION_GRANTED) {
    return true;
  }else
    return false;
}
class PermissionResult {
    private String permission;
    private Integer grantResult;

  public PermissionResult(String permission, Integer grantResult) {
    this.permission = permission;
    this.grantResult = grantResult;
  }

  public String getPermission() {
    return permission;
  }

  public void setPermission(String permission) {
    this.permission = permission;
  }

  public Integer getGrantResult() {
    return grantResult;
  }

  public void setGrantResult(Integer grantResult) {
    this.grantResult = grantResult;
  }
}
private List<String> parsePremissionToNative(String permissionFlutter){

    List<String> permissionList = new ArrayList<>();

  switch (permissionFlutter) {
    case "calendar":
      permissionList.add(( Manifest.permission.READ_CALENDAR));
      break;
    case "camera":
      permissionList.add(( Manifest.permission.CAMERA));
      break;
    case "contacts":
      permissionList.add(( Manifest.permission.READ_CONTACTS));
      permissionList.add(( Manifest.permission.GET_ACCOUNTS));

      break;
    case "location":
      permissionList.add(( Manifest.permission.ACCESS_COARSE_LOCATION));
      permissionList.add(( Manifest.permission.ACCESS_FINE_LOCATION));

      break;
    case "locationAlways":
      permissionList.add(( Manifest.permission.ACCESS_COARSE_LOCATION));
      permissionList.add(( Manifest.permission.ACCESS_FINE_LOCATION));
      break;
    case "locationWhenInUse":
      permissionList.add(( Manifest.permission.ACCESS_COARSE_LOCATION));
      permissionList.add(( Manifest.permission.ACCESS_FINE_LOCATION));
      break;
    case "phone":
      permissionList.add(( Manifest.permission.READ_CALL_LOG));
      permissionList.add(( Manifest.permission.READ_PHONE_STATE));
      break;
    case "storage":
      permissionList.add(( Manifest.permission.READ_EXTERNAL_STORAGE));
      permissionList.add(( Manifest.permission.WRITE_EXTERNAL_STORAGE));
      break;
    default:
      break;
  }


  return permissionList;

}

//  private PermissionResult AddToLists(String premission) {
//    Integer grandPremission;
//    if (checkSelfPermission(activity.getApplicationContext(), premission)) {
//      grandPremission = 1;
//    } else {
//      grandPremission = 0;
//    }
//    return new PermissionResult(premission,grandPremission);
//  }

  private CheckPoint getCheckPointFromJson(String jsonStr) {
    try {
      Log.d("Json string from JS: ", jsonStr);
      JSONObject object = new JSONObject(jsonStr);
      CheckPoint checkPoint;

      String checkPointType = object.getString("checkpoint_type");
      if (CheckPointType.valueOf(checkPointType) == CheckPointType.LAUNCH) {
        Launch launch = new Launch();
        checkPoint = launch;
      } else if (CheckPointType.valueOf(checkPointType) == CheckPointType.REGISTER) {
        checkPoint = new Registration(object);
      } else if (CheckPointType.valueOf(checkPointType) == CheckPointType.LOGIN) {
        checkPoint = new Login(object);
      } else if (CheckPointType.valueOf(checkPointType) == CheckPointType.TRANSACTION) {
        checkPoint = new Transaction(object);
      } else if (CheckPointType.valueOf(checkPointType) == CheckPointType.ADD_PAYMENT_METHOD) {
        checkPoint = new AddPaymentMethod(object);
      } else if (CheckPointType.valueOf(checkPointType) == CheckPointType.PASSWORD_CHANGE) {
        checkPoint = new PasswordChange(object);
      } else if (CheckPointType.valueOf(checkPointType) == CheckPointType.VIEW_CARD_DETAILS) {
        checkPoint = new ViewCardDetails(object);  
      } else if (CheckPointType.valueOf(checkPointType) == CheckPointType.UPDATE_USER_INFO) {
        checkPoint = new UpdateUserInfo(object);
      } else if (CheckPointType.valueOf(checkPointType) == CheckPointType.EXTERNAL_CARD_TRANSACTION) {
        checkPoint = new ExternalCardTransaction(object);
      } else { // if (CheckPointType.valueOf(checkPointType) == CheckPointType.GENERAL) {
        checkPoint = new General();
      }
      return checkPoint;
    } catch (JSONException e) {
      return null;
    }
  }

  @Override
  public void onDetachedFromActivityForConfigChanges() {

  }

  @Override
  public void onReattachedToActivityForConfigChanges(@NonNull ActivityPluginBinding binding) {

  }

  @Override
  public void onDetachedFromActivity() {

  }

  @Override
  public void onDetachedFromEngine(@NonNull FlutterPluginBinding binding) {

    channel.setMethodCallHandler(null);
  }

  @Override
  public void onAttachedToActivity(@NonNull ActivityPluginBinding binding) {
    activity = binding.getActivity();

  }
}
